# ExtSelectValue


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**name** | **str** |  | [optional] 

## Example

```python
from src.client.generated.models.ext_select_value import ExtSelectValue

# TODO update the JSON string below
json = "{}"
# create an instance of ExtSelectValue from a JSON string
ext_select_value_instance = ExtSelectValue.from_json(json)
# print the JSON string representation of the object
print(ExtSelectValue.to_json())

# convert the object into a dict
ext_select_value_dict = ext_select_value_instance.to_dict()
# create an instance of ExtSelectValue from a dict
ext_select_value_from_dict = ExtSelectValue.from_dict(ext_select_value_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


